@@ -358,8 +358,8 @@ int main(int argc, char ** argv){
 		rect_any->_type = TC_GNOME_Magnifier_RectBounds;
 		rect_any->_value = ORBit_copy_value (rectangle, TC_GNOME_Magnifier_RectBounds);
 		properties = GNOME_Magnifier_Magnifier_getProperties (magnifier, &ev);
-		Bonobo_PropertyBag_setValue (properties, "target-display-bounds", rect_any, NULL);
-		bonobo_object_release_unref (properties, NULL);
+		Bonobo_PropertyBag_setValue (properties, "target-display-bounds", rect_any, &ev);
+		bonobo_object_release_unref (properties, &ev);
 		break;
         case 'X':
 		if (zoom_region == CORBA_OBJECT_NIL) return -1;
